{% extends "admin/change_list.html" %}

{% block extrahead %}
{{ block.super }}
{{ adminchart_chartjs_config|json_script:"adminchart-chartjs-config" }}
{% endblock %}

{% block pretitle %}
{{ block.super }}
<div id="admincharts"></div>
{% endblock %}
